@@ -38,6 +38,7 @@ import javax.servlet.http.HttpServletResponse;
 import org.apache.catalina.Globals;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
+import org.apache.tomcat.util.http.Method;
 import org.apache.tomcat.util.http.RequestUtil;
 import org.apache.tomcat.util.http.ResponseUtil;
 import org.apache.tomcat.util.http.parser.MediaType;
@@ -407,7 +408,7 @@ public class CorsFilter extends GenericFilter {
             response.addHeader(RESPONSE_HEADER_ACCESS_CONTROL_EXPOSE_HEADERS, exposedHeadersString);
         }
 
-        if ("OPTIONS".equals(method)) {
+        if (Method.OPTIONS.equals(method)) {
             // For an OPTIONS request, the response will vary based on the
             // value or absence of the following headers. Hence, they need to be
             // included in the Vary header.
@@ -556,7 +557,7 @@ public class CorsFilter extends GenericFilter {
             return CORSRequestType.INVALID_CORS;
         }
         switch (method) {
-            case "OPTIONS":
+            case Method.OPTIONS:
                 String accessControlRequestMethodHeader =
                         request.getHeader(REQUEST_HEADER_ACCESS_CONTROL_REQUEST_METHOD);
                 if (accessControlRequestMethodHeader != null) {
@@ -566,10 +567,10 @@ public class CorsFilter extends GenericFilter {
                     return CORSRequestType.PRE_FLIGHT;
                 }
                 return CORSRequestType.ACTUAL;
-            case "GET":
-            case "HEAD":
+            case Method.GET:
+            case Method.HEAD:
                 return CORSRequestType.SIMPLE;
-            case "POST":
+            case Method.POST:
                 String mediaType = MediaType.parseMediaTypeOnly(request.getContentType());
                 if (mediaType == null || SIMPLE_HTTP_REQUEST_CONTENT_TYPE_VALUES.contains(mediaType)) {
                     return CORSRequestType.SIMPLE;
