@@ -140,6 +140,7 @@ public class JspC extends Task implements Options {
     protected static final String SWITCH_QUOTE_ATTRIBUTE_EL = "-quoteAttributeEL";
     protected static final String SWITCH_NO_QUOTE_ATTRIBUTE_EL = "-no-quoteAttributeEL";
     protected static final String SWITCH_THREAD_COUNT = "-threadCount";
+    protected static final String SWITCH_USENONSTANDARD_TAG_OPTIMIZATIONS = "-useNonstandardTagOptimizations";
     protected static final String SHOW_SUCCESS = "-s";
     protected static final String LIST_ERRORS = "-l";
     protected static final int INC_WEBXML = 10;
@@ -271,6 +272,7 @@ public class JspC extends Task implements Options {
     protected int argPos;
     protected boolean fullstop = false;
     protected String[] args;
+    protected String useNonstandardTagOptimizations;
 
     public static void main(String[] arg) {
         if (arg.length == 0) {
@@ -403,6 +405,8 @@ public class JspC extends Task implements Options {
                 setQuoteAttributeEL(false);
             } else if (tok.equals(SWITCH_THREAD_COUNT)) {
                 setThreadCount(nextArg());
+            } else if (tok.equals(SWITCH_USENONSTANDARD_TAG_OPTIMIZATIONS)) {
+                setUseNonstandardTagOptimizations(nextArg());
             } else {
                 if (tok.startsWith("-")) {
                     throw new JasperException(Localizer.getMessage("jspc.error.unknownOption", tok));
@@ -809,7 +813,7 @@ public class JspC extends Task implements Options {
         }
         try {
             uriRoot = resolveFile(s).getCanonicalPath();
-        } catch (Exception ex) {
+        } catch (Exception e) {
             uriRoot = s;
         }
     }
@@ -1030,6 +1034,15 @@ public class JspC extends Task implements Options {
         failOnError = b;
     }
 
+    /**
+     * Sets the set of custom tags to use nonstandard optimizations.
+     *
+     * @param useNonstandardTagOptimizations which tags to override
+     */
+    public void setUseNonstandardTagOptimizations(String useNonstandardTagOptimizations) {
+        this.useNonstandardTagOptimizations = useNonstandardTagOptimizations;
+    }
+
     /**
      * @return <code>true</code> if an exception will be thrown in case of a compilation error.
      */
@@ -1450,7 +1463,7 @@ public class JspC extends Task implements Options {
                             errorCount++;
                             log.error(Localizer.getMessage("jspc.error.compilation"), e);
                         }
-                    } catch (InterruptedException e) {
+                    } catch (InterruptedException ignore) {
                         // Ignore
                     }
                 }
@@ -1554,8 +1567,8 @@ public class JspC extends Task implements Options {
                     mapout.write(Localizer.getMessage("jspc.webinc.footer"));
                 }
                 mapout.close();
-            } catch (IOException ioe) {
-                // nothing to do if it fails since we are done with it
+            } catch (IOException ignore) {
+                // Nothing to do if it fails since we are done with it.
             }
         }
     }
@@ -1727,7 +1740,7 @@ public class JspC extends Task implements Options {
                     uriRoot = froot.getCanonicalPath();
                 }
             }
-        } catch (IOException ioe) {
+        } catch (IOException ignore) {
             // Missing uriRoot will be handled in the caller.
         }
     }
@@ -1753,9 +1766,9 @@ public class JspC extends Task implements Options {
         FileInputStream fis = new FileInputStream(file);
         try {
             return webxmlEncoding != null ? new InputStreamReader(fis, webxmlEncoding) : new InputStreamReader(fis);
-        } catch (IOException ex) {
+        } catch (IOException ioe) {
             fis.close();
-            throw ex;
+            throw ioe;
         }
     }
 
@@ -1763,9 +1776,9 @@ public class JspC extends Task implements Options {
         FileOutputStream fos = new FileOutputStream(file);
         try {
             return webxmlEncoding != null ? new OutputStreamWriter(fos, webxmlEncoding) : new OutputStreamWriter(fos);
-        } catch (IOException ex) {
+        } catch (IOException ioe) {
             fos.close();
-            throw ex;
+            throw ioe;
         }
     }
 
@@ -1783,4 +1796,9 @@ public class JspC extends Task implements Options {
             return null;
         }
     }
+
+    @Override
+    public String getUseNonstandardTagOptimizations() {
+        return useNonstandardTagOptimizations;
+    }
 }
