@@ -169,7 +169,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
                 jspDocParser.isValidating = true;
                 try {
                     source.getByteStream().close();
-                } catch (IOException e2) {
+                } catch (IOException ioe) {
                     // ignore
                 }
                 source = JspUtil.getInputSource(path, jar, jspDocParser.ctxt);
@@ -177,7 +177,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
             } finally {
                 try {
                     source.getByteStream().close();
-                } catch (IOException e) {
+                } catch (IOException ioe) {
                     // ignore
                 }
             }
@@ -276,9 +276,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
         /*
          * Notice that due to a bug in the underlying SAX parser, the attributes must be enumerated in descending order.
          */
-        boolean isTaglib = false;
         for (int i = attrs.getLength() - 1; i >= 0; i--) {
-            isTaglib = false;
             String attrQName = attrs.getQName(i);
             if (!attrQName.startsWith("xmlns")) {
                 if (nonTaglibAttrs == null) {
@@ -287,6 +285,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
                 nonTaglibAttrs.addAttribute(attrs.getURI(i), attrs.getLocalName(i), attrs.getQName(i), attrs.getType(i),
                         attrs.getValue(i));
             } else {
+                boolean isTaglib;
                 if (attrQName.startsWith("xmlns:jsp")) {
                     isTaglib = true;
                 } else {
@@ -311,7 +310,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
             }
         }
 
-        Node node = null;
+        Node node;
 
         if (tagDependentPending && JSP_URI.equals(uri) && localName.equals(BODY_ACTION)) {
             tagDependentPending = false;
@@ -363,8 +362,8 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
      *
      * The SAX does not call this method with all of the template text, but may invoke this method with chunks of it.
      * This is a problem when we try to determine if the text contains only whitespaces, or when we are looking for an
-     * EL expression string. Therefore it is necessary to buffer and concatenate the chunks and process the concatenated
-     * text later (at beginTag and endTag)
+     * EL expression string. Therefore, it is necessary to buffer and concatenate the chunks and process the
+     * concatenated text later (at beginTag and endTag)
      *
      * @param buf The characters
      *
@@ -427,7 +426,8 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
             int column = startMark.getColumnNumber();
 
             CharArrayWriter ttext = new CharArrayWriter();
-            int lastCh = 0, elType = 0;
+            int lastCh = 0;
+            int elType;
             for (int i = 0; i < charBuffer.length(); i++) {
 
                 int ch = charBuffer.charAt(i);
@@ -533,12 +533,12 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
                     continue;
                 }
                 // Ignore any whitespace (including spaces, carriage returns,
-                // line feeds, and tabs, that appear at the beginning and at
+                // line feeds, and tabs) that appear at the beginning and at
                 // the end of the body of the <jsp:attribute> action, if the
                 // action's 'trim' attribute is set to TRUE (default).
                 // In addition, any textual nodes in the <jsp:attribute> that
-                // have only white space are dropped from the document, with
-                // the exception of leading and trailing white-space-only
+                // have only white space are dropped from the document,
+                // except for leading and trailing white-space-only
                 // textual nodes in a <jsp:attribute> whose 'trim' attribute
                 // is set to FALSE, which must be kept verbatim.
                 if (i == 0) {
@@ -563,7 +563,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
             tagDependentNesting--;
         }
 
-        if (scriptlessBodyNode != null && current.equals(scriptlessBodyNode)) {
+        if (current.equals(scriptlessBodyNode)) {
             scriptlessBodyNode = null;
         }
 
@@ -717,7 +717,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
     private Node parseStandardAction(String qName, String localName, Attributes nonTaglibAttrs,
             Attributes nonTaglibXmlnsAttrs, Attributes taglibAttrs, Mark start) throws SAXException {
 
-        Node node = null;
+        Node node;
 
         if (localName.equals(ROOT_ACTION)) {
             if (!(current instanceof Node.Root)) {
@@ -856,7 +856,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
 
         String prefix = getPrefix(qName);
 
-        Node.CustomTag ret = null;
+        Node.CustomTag ret;
         if (tagInfo != null) {
             ret = new Node.CustomTag(qName, prefix, localName, uri, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs,
                     start, parent, tagInfo, tagHandlerClass);
@@ -998,7 +998,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
     private void checkPrefix(String uri, String qName) {
 
         String prefix = getPrefix(qName);
-        if (prefix.length() > 0) {
+        if (!prefix.isEmpty()) {
             pageInfo.addPrefix(prefix);
             if ("jsp".equals(prefix) && !JSP_URI.equals(uri)) {
                 pageInfo.setIsJspPrefixHijacked(true);
