@@ -37,18 +37,18 @@ import javax.management.RuntimeOperationsException;
 import javax.management.ServiceNotFoundException;
 
 import org.apache.tomcat.util.buf.StringUtils;
-import org.apache.tomcat.util.buf.StringUtils.Function;
+import org.apache.tomcat.util.res.StringManager;
 
 
 /**
- * <p>Internal configuration information for a managed bean (MBean)
- * descriptor.</p>
- *
- * @author Craig R. McClanahan
+ * <p>
+ * Internal configuration information for a managed bean (MBean) descriptor.
+ * </p>
  */
 public class ManagedBean implements java.io.Serializable {
 
     private static final long serialVersionUID = 1L;
+    private static final StringManager sm = StringManager.getManager(ManagedBean.class);
 
     private static final String BASE_MBEAN = "org.apache.tomcat.util.modeler.BaseModelMBean";
     // ----------------------------------------------------- Instance Variables
@@ -57,14 +57,13 @@ public class ManagedBean implements java.io.Serializable {
 
     private final ReadWriteLock mBeanInfoLock = new ReentrantReadWriteLock();
     /**
-     * The <code>ModelMBeanInfo</code> object that corresponds
-     * to this <code>ManagedBean</code> instance.
+     * The <code>ModelMBeanInfo</code> object that corresponds to this <code>ManagedBean</code> instance.
      */
     private transient volatile MBeanInfo info = null;
 
-    private Map<String,AttributeInfo> attributes = new HashMap<>();
+    private final Map<String,AttributeInfo> attributes = new HashMap<>();
 
-    private Map<String,OperationInfo> operations = new HashMap<>();
+    private final Map<String,OperationInfo> operations = new HashMap<>();
 
     protected String className = BASE_MBEAN;
     protected String description = null;
@@ -72,14 +71,14 @@ public class ManagedBean implements java.io.Serializable {
     protected String group = null;
     protected String name = null;
 
-    private NotificationInfo notifications[] = new NotificationInfo[0];
+    private NotificationInfo[] notifications = new NotificationInfo[0];
     protected String type = null;
 
     /**
      * Constructor. Will add default attributes.
      */
     public ManagedBean() {
-        AttributeInfo ai=new AttributeInfo();
+        AttributeInfo ai = new AttributeInfo();
         ai.setName("modelerType");
         ai.setDescription("Type of the modeled resource. Can be set only once");
         ai.setType("java.lang.String");
@@ -99,10 +98,9 @@ public class ManagedBean implements java.io.Serializable {
 
 
     /**
-     * The fully qualified name of the Java class of the MBean
-     * described by this descriptor.  If not specified, the standard JMX
-     * class (<code>javax.management.modelmbean.RequiredModeLMBean</code>)
-     * will be utilized.
+     * The fully qualified name of the Java class of the MBean described by this descriptor. If not specified, the
+     * standard JMX class (<code>javax.management.modelmbean.RequiredModeLMBean</code>) will be utilized.
+     *
      * @return the class name
      */
     public String getClassName() {
@@ -139,8 +137,8 @@ public class ManagedBean implements java.io.Serializable {
 
 
     /**
-     * @return the (optional) <code>ObjectName</code> domain in which
-     *  this MBean should be registered in the MBeanServer.
+     * @return the (optional) <code>ObjectName</code> domain in which this MBean should be registered in the
+     *             MBeanServer.
      */
     public String getDomain() {
         return this.domain;
@@ -164,8 +162,8 @@ public class ManagedBean implements java.io.Serializable {
 
 
     /**
-     * @return the name of this managed bean, which must be unique
-     *  among all MBeans managed by a particular MBeans server.
+     * @return the name of this managed bean, which must be unique among all MBeans managed by a particular MBeans
+     *             server.
      */
     public String getName() {
         return this.name;
@@ -199,9 +197,8 @@ public class ManagedBean implements java.io.Serializable {
 
 
     /**
-     * @return the fully qualified name of the Java class of the resource
-     * implementation class described by the managed bean described
-     * by this descriptor.
+     * @return the fully qualified name of the Java class of the resource implementation class described by the managed
+     *             bean described by this descriptor.
      */
     public String getType() {
         return this.type;
@@ -239,10 +236,8 @@ public class ManagedBean implements java.io.Serializable {
     public void addNotification(NotificationInfo notification) {
         mBeanInfoLock.writeLock().lock();
         try {
-            NotificationInfo results[] =
-                new NotificationInfo[notifications.length + 1];
-            System.arraycopy(notifications, 0, results, 0,
-                             notifications.length);
+            NotificationInfo[] results = new NotificationInfo[notifications.length + 1];
+            System.arraycopy(notifications, 0, results, 0, notifications.length);
             results[notifications.length] = notification;
             notifications = results;
             this.info = null;
@@ -263,30 +258,25 @@ public class ManagedBean implements java.io.Serializable {
 
 
     /**
-     * Create and return a <code>ModelMBean</code> that has been
-     * preconfigured with the <code>ModelMBeanInfo</code> information
-     * for this managed bean, and is associated with the specified
-     * managed object instance.  The returned <code>ModelMBean</code>
-     * will <strong>NOT</strong> have been registered with our
-     * <code>MBeanServer</code>.
+     * Create and return a <code>ModelMBean</code> that has been preconfigured with the <code>ModelMBeanInfo</code>
+     * information for this managed bean, and is associated with the specified managed object instance. The returned
+     * <code>ModelMBean</code> will <strong>NOT</strong> have been registered with our <code>MBeanServer</code>.
+     *
+     * @param instance Instanced of the managed object, or <code>null</code> for no associated instance
      *
-     * @param instance Instanced of the managed object, or <code>null</code>
-     *  for no associated instance
      * @return the MBean
-     * @exception InstanceNotFoundException if the managed resource
-     *  object cannot be found
-     * @exception MBeanException if a problem occurs instantiating the
-     *  <code>ModelMBean</code> instance
+     *
+     * @exception InstanceNotFoundException  if the managed resource object cannot be found
+     * @exception MBeanException             if a problem occurs instantiating the <code>ModelMBean</code> instance
      * @exception RuntimeOperationsException if a JMX runtime error occurs
      */
     public DynamicMBean createMBean(Object instance)
-        throws InstanceNotFoundException,
-        MBeanException, RuntimeOperationsException {
+            throws InstanceNotFoundException, MBeanException, RuntimeOperationsException {
 
-        BaseModelMBean mbean = null;
+        BaseModelMBean mbean;
 
         // Load the ModelMBean implementation class
-        if(getClassName().equals(BASE_MBEAN)) {
+        if (getClassName().equals(BASE_MBEAN)) {
             // Skip introspection
             mbean = new BaseModelMBean();
         } else {
@@ -295,22 +285,22 @@ public class ManagedBean implements java.io.Serializable {
             try {
                 clazz = Class.forName(getClassName());
             } catch (Exception e) {
+                // Ignore
             }
 
-            if( clazz==null ) {
+            if (clazz == null) {
                 try {
-                    ClassLoader cl= Thread.currentThread().getContextClassLoader();
-                    if ( cl != null) {
-                        clazz= cl.loadClass(getClassName());
+                    ClassLoader cl = Thread.currentThread().getContextClassLoader();
+                    if (cl != null) {
+                        clazz = cl.loadClass(getClassName());
                     }
                 } catch (Exception e) {
-                    ex=e;
+                    ex = e;
                 }
             }
 
-            if( clazz==null) {
-                throw new MBeanException
-                    (ex, "Cannot load ModelMBean class " + getClassName());
+            if (clazz == null) {
+                throw new MBeanException(ex, sm.getString("managedMBean.cannotLoadClass", getClassName()));
             }
             try {
                 // Stupid - this will set the default minfo first....
@@ -318,21 +308,15 @@ public class ManagedBean implements java.io.Serializable {
             } catch (RuntimeOperationsException e) {
                 throw e;
             } catch (Exception e) {
-                throw new MBeanException
-                    (e, "Cannot instantiate ModelMBean of class " +
-                     getClassName());
+                throw new MBeanException(e, sm.getString("managedMBean.cannotInstantiateClass", getClassName()));
             }
         }
 
         mbean.setManagedBean(this);
 
         // Set the managed resource (if any)
-        try {
-            if (instance != null) {
-                mbean.setManagedResource(instance, "ObjectReference");
-            }
-        } catch (InstanceNotFoundException e) {
-            throw e;
+        if (instance != null) {
+            mbean.setManagedResource(instance, "ObjectReference");
         }
 
         return mbean;
@@ -340,8 +324,8 @@ public class ManagedBean implements java.io.Serializable {
 
 
     /**
-     * Create and return a <code>ModelMBeanInfo</code> object that
-     * describes this entire managed bean.
+     * Create and return a <code>ModelMBeanInfo</code> object that describes this entire managed bean.
+     *
      * @return the MBean info
      */
     MBeanInfo getMBeanInfo() {
@@ -360,36 +344,29 @@ public class ManagedBean implements java.io.Serializable {
         try {
             if (info == null) {
                 // Create subordinate information descriptors as required
-                AttributeInfo attrs[] = getAttributes();
-                MBeanAttributeInfo attributes[] =
-                    new MBeanAttributeInfo[attrs.length];
+                AttributeInfo[] attrs = getAttributes();
+                MBeanAttributeInfo[] attributes = new MBeanAttributeInfo[attrs.length];
                 for (int i = 0; i < attrs.length; i++) {
                     attributes[i] = attrs[i].createAttributeInfo();
                 }
 
-                OperationInfo opers[] = getOperations();
-                MBeanOperationInfo operations[] =
-                    new MBeanOperationInfo[opers.length];
+                OperationInfo[] opers = getOperations();
+                MBeanOperationInfo[] operations = new MBeanOperationInfo[opers.length];
                 for (int i = 0; i < opers.length; i++) {
                     operations[i] = opers[i].createOperationInfo();
                 }
 
 
-                NotificationInfo notifs[] = getNotifications();
-                MBeanNotificationInfo notifications[] =
-                    new MBeanNotificationInfo[notifs.length];
+                NotificationInfo[] notifs = getNotifications();
+                MBeanNotificationInfo[] notifications = new MBeanNotificationInfo[notifs.length];
                 for (int i = 0; i < notifs.length; i++) {
                     notifications[i] = notifs[i].createNotificationInfo();
                 }
 
 
                 // Construct and return a new ModelMBeanInfo object
-                info = new MBeanInfo(getClassName(),
-                                     getDescription(),
-                                     attributes,
-                                     new MBeanConstructorInfo[] {},
-                                     operations,
-                                     notifications);
+                info = new MBeanInfo(getClassName(), getDescription(), attributes, new MBeanConstructorInfo[] {},
+                        operations, notifications);
             }
 
             return info;
@@ -431,15 +408,12 @@ public class ManagedBean implements java.io.Serializable {
         AttributeInfo attrInfo = attributes.get(aname);
         // Look up the actual operation to be used
         if (attrInfo == null) {
-            throw new AttributeNotFoundException(" Cannot find attribute " + aname + " for " + resource);
+            throw new AttributeNotFoundException(sm.getString("managedMBean.noAttribute", aname, resource));
         }
 
         String getMethod = attrInfo.getGetMethod();
-        if (getMethod == null) {
-            throw new AttributeNotFoundException("Cannot find attribute " + aname + " get method name");
-        }
 
-        Object object = null;
+        Object object;
         NoSuchMethodException exception = null;
         try {
             object = mbean;
@@ -447,18 +421,17 @@ public class ManagedBean implements java.io.Serializable {
         } catch (NoSuchMethodException e) {
             exception = e;
         }
-        if (m== null && resource != null) {
+        if (m == null && resource != null) {
             try {
                 object = resource;
                 m = object.getClass().getMethod(getMethod, NO_ARGS_PARAM_SIG);
-                exception=null;
+                exception = null;
             } catch (NoSuchMethodException e) {
                 exception = e;
             }
         }
         if (exception != null) {
-            throw new ReflectionException(exception,
-                                          "Cannot find getter method " + getMethod);
+            throw new ReflectionException(exception, sm.getString("managedMBean.noGet", getMethod, resource));
         }
 
         return m;
@@ -471,21 +444,16 @@ public class ManagedBean implements java.io.Serializable {
 
         AttributeInfo attrInfo = attributes.get(aname);
         if (attrInfo == null) {
-            throw new AttributeNotFoundException(" Cannot find attribute " + aname);
+            throw new AttributeNotFoundException(sm.getString("managedMBean.noAttribute", aname, resource));
         }
 
         // Look up the actual operation to be used
         String setMethod = attrInfo.getSetMethod();
-        if (setMethod == null) {
-            throw new AttributeNotFoundException("Cannot find attribute " + aname + " set method name");
-        }
+        String argType = attrInfo.getType();
 
-        String argType=attrInfo.getType();
+        Class<?>[] signature = new Class[] { BaseModelMBean.getAttributeClass(argType) };
 
-        Class<?> signature[] =
-            new Class[] { BaseModelMBean.getAttributeClass( argType ) };
-
-        Object object = null;
+        Object object;
         NoSuchMethodException exception = null;
         try {
             object = bean;
@@ -497,15 +465,13 @@ public class ManagedBean implements java.io.Serializable {
             try {
                 object = resource;
                 m = object.getClass().getMethod(setMethod, signature);
-                exception=null;
+                exception = null;
             } catch (NoSuchMethodException e) {
                 exception = e;
             }
         }
         if (exception != null) {
-            throw new ReflectionException(exception,
-                                          "Cannot find setter method " + setMethod +
-                    " " + resource);
+            throw new ReflectionException(exception, sm.getString("managedMBean.noSet", setMethod, resource));
         }
 
         return m;
@@ -524,24 +490,21 @@ public class ManagedBean implements java.io.Serializable {
         }
         if (params.length != signature.length) {
             throw new RuntimeOperationsException(
-                    new IllegalArgumentException(
-                            "Inconsistent arguments and signature"),
-                    "Inconsistent arguments and signature");
+                    new IllegalArgumentException(sm.getString("managedMBean.inconsistentArguments")),
+                    sm.getString("managedMBean.inconsistentArguments"));
         }
 
         // Acquire the ModelMBeanOperationInfo information for
         // the requested operation
-        OperationInfo opInfo =
-                operations.get(createOperationKey(aname, signature));
+        OperationInfo opInfo = operations.get(createOperationKey(aname, signature));
         if (opInfo == null) {
-            throw new MBeanException(new ServiceNotFoundException(
-                    "Cannot find operation " + aname),
-                    "Cannot find operation " + aname);
+            throw new MBeanException(new ServiceNotFoundException(sm.getString("managedMBean.noOperation", aname)),
+                    sm.getString("managedMBean.noOperation", aname));
         }
 
         // Prepare the signature required by Java reflection APIs
         // FIXME - should we use the signature from opInfo?
-        Class<?> types[] = new Class[signature.length];
+        Class<?>[] types = new Class[signature.length];
         for (int i = 0; i < signature.length; i++) {
             types[i] = BaseModelMBean.getAttributeClass(signature[i]);
         }
@@ -549,7 +512,7 @@ public class ManagedBean implements java.io.Serializable {
         // Locate the method to be invoked, either in this MBean itself
         // or in the corresponding managed resource
         // FIXME - Accessible methods in superinterfaces?
-        Object object = null;
+        Object object;
         Exception exception = null;
         try {
             object = bean;
@@ -566,8 +529,7 @@ public class ManagedBean implements java.io.Serializable {
             exception = e;
         }
         if (method == null) {
-            throw new ReflectionException(exception, "Cannot find method "
-                    + aname + " with this signature");
+            throw new ReflectionException(exception, sm.getString("managedMBean.noMethod", aname));
         }
 
         return method;
@@ -577,9 +539,9 @@ public class ManagedBean implements java.io.Serializable {
     private String createOperationKey(OperationInfo operation) {
         StringBuilder key = new StringBuilder(operation.getName());
         key.append('(');
-        StringUtils.join(operation.getSignature(), ',', new Function<ParameterInfo>() {
-            @Override public String apply(ParameterInfo t) { return t.getType(); }}, key);
+        StringUtils.join(operation.getSignature(), ',', FeatureInfo::getType, key);
         key.append(')');
+
         return key.toString().intern();
     }
 
