@@ -139,7 +139,7 @@ public class Util {
     static byte[] generateMask() {
         // SecureRandom is not thread-safe so need to make sure only one thread
         // uses it at a time. In theory, the pool could grow to the same size
-        // as the number of request processing threads. In reality it will be
+        // as the number of request processing threads. In reality, it will be
         // a lot smaller.
 
         // Get a SecureRandom from the pool
@@ -167,17 +167,17 @@ public class Util {
 
 
     static Class<?> getMessageType(MessageHandler listener) {
-        return Util.getGenericType(MessageHandler.class, listener.getClass()).getClazz();
+        return getGenericType(MessageHandler.class, listener.getClass()).getClazz();
     }
 
 
     private static Class<?> getDecoderType(Class<? extends Decoder> decoder) {
-        return Util.getGenericType(Decoder.class, decoder).getClazz();
+        return getGenericType(Decoder.class, decoder).getClazz();
     }
 
 
     static Class<?> getEncoderType(Class<? extends Encoder> encoder) {
-        return Util.getGenericType(Encoder.class, encoder).getClazz();
+        return getGenericType(Encoder.class, encoder).getClazz();
     }
 
 
@@ -205,7 +205,7 @@ public class Util {
         Class<? extends T> superClazz = (Class<? extends T>) clazz.getSuperclass();
         if (superClazz == null) {
             // Finished looking up the class hierarchy without finding anything
-            return null;
+            throw new IllegalStateException();
         }
 
         TypeResult superClassTypeResult = getGenericType(type, superClazz);
@@ -221,8 +221,8 @@ public class Util {
             // the interface of interest
             // Map that unknown type to the generic types defined in this class
             ParameterizedType superClassType = (ParameterizedType) clazz.getGenericSuperclass();
-            TypeResult result = getTypeParameter(clazz,
-                    superClassType.getActualTypeArguments()[superClassTypeResult.getIndex()]);
+            TypeResult result =
+                    getTypeParameter(clazz, superClassType.getActualTypeArguments()[superClassTypeResult.getIndex()]);
             result.incrementDimension(superClassTypeResult.getDimension());
             if (result.getClazz() != null && result.getDimension() > 0) {
                 superClassTypeResult = result;
@@ -251,7 +251,7 @@ public class Util {
         }
 
         // Error will be logged further up the call stack
-        return null;
+        throw new IllegalStateException();
     }
 
 
@@ -276,7 +276,7 @@ public class Util {
                     return new TypeResult(null, i, 0);
                 }
             }
-            return null;
+            throw new IllegalStateException();
         }
     }
 
@@ -284,12 +284,11 @@ public class Util {
     public static boolean isPrimitive(Class<?> clazz) {
         if (clazz.isPrimitive()) {
             return true;
-        } else if (clazz.equals(Boolean.class) || clazz.equals(Byte.class) || clazz.equals(Character.class) ||
-                clazz.equals(Double.class) || clazz.equals(Float.class) || clazz.equals(Integer.class) ||
-                clazz.equals(Long.class) || clazz.equals(Short.class)) {
-            return true;
+        } else {
+            return clazz.equals(Boolean.class) || clazz.equals(Byte.class) || clazz.equals(Character.class) ||
+                    clazz.equals(Double.class) || clazz.equals(Float.class) || clazz.equals(Integer.class) ||
+                    clazz.equals(Long.class) || clazz.equals(Short.class);
         }
-        return false;
     }
 
 
@@ -363,12 +362,12 @@ public class Util {
                         // Don't need this instance, so destroy it
                         instanceManager.destroyInstance(instance);
                     }
-                } catch (ReflectiveOperationException | IllegalArgumentException | SecurityException
-                        | NamingException e) {
+                } catch (ReflectiveOperationException | IllegalArgumentException | SecurityException |
+                        NamingException e) {
                     throw new DeploymentException(
                             sm.getString("pojoMethodMapping.invalidDecoder", decoderClazz.getName()), e);
                 }
-                DecoderEntry entry = new DecoderEntry(Util.getDecoderType(decoderClazz), decoderClazz);
+                DecoderEntry entry = new DecoderEntry(getDecoderType(decoderClazz), decoderClazz);
                 result.add(entry);
             }
         }
@@ -398,13 +397,16 @@ public class Util {
             // the types expected by the frame handling code
         } else if (byte[].class.isAssignableFrom(target)) {
             boolean whole = MessageHandler.Whole.class.isAssignableFrom(listener.getClass());
-            MessageHandlerResult result = new MessageHandlerResult(whole
-                    ? new PojoMessageHandlerWholeBinary(listener, getOnMessageMethod(listener), session, endpointConfig,
-                            matchDecoders(target, endpointConfig, true, ((WsSession) session).getInstanceManager()),
-                            new Object[1], 0, true, -1, false, -1)
-                    : new PojoMessageHandlerPartialBinary(listener, getOnMessagePartialMethod(listener), session,
-                            new Object[2], 0, true, 1, -1, -1),
-                    MessageHandlerResultType.BINARY);
+            MessageHandlerResult result =
+                    new MessageHandlerResult(whole ?
+                            new PojoMessageHandlerWholeBinary(listener, getOnMessageMethod(listener), session,
+                                    endpointConfig,
+                                    matchDecoders(target, endpointConfig, true,
+                                            ((WsSession) session).getInstanceManager()),
+                                    new Object[1], 0, true, -1, false, -1) :
+                            new PojoMessageHandlerPartialBinary(listener, getOnMessagePartialMethod(listener), session,
+                                    new Object[2], 0, true, 1, -1, -1),
+                            MessageHandlerResultType.BINARY);
             results.add(result);
         } else if (InputStream.class.isAssignableFrom(target)) {
             MessageHandlerResult result = new MessageHandlerResult(
@@ -423,17 +425,17 @@ public class Util {
         } else {
             // Handler needs wrapping and requires decoder to convert it to one
             // of the types expected by the frame handling code
-            DecoderMatch decoderMatch = matchDecoders(target, endpointConfig,
-                    ((WsSession) session).getInstanceManager());
+            DecoderMatch decoderMatch =
+                    matchDecoders(target, endpointConfig, ((WsSession) session).getInstanceManager());
             Method m = getOnMessageMethod(listener);
-            if (decoderMatch.getBinaryDecoders().size() > 0) {
+            if (!decoderMatch.getBinaryDecoders().isEmpty()) {
                 MessageHandlerResult result = new MessageHandlerResult(
                         new PojoMessageHandlerWholeBinary(listener, m, session, endpointConfig,
                                 decoderMatch.getBinaryDecoders(), new Object[1], 0, false, -1, false, -1),
                         MessageHandlerResultType.BINARY);
                 results.add(result);
             }
-            if (decoderMatch.getTextDecoders().size() > 0) {
+            if (!decoderMatch.getTextDecoders().isEmpty()) {
                 MessageHandlerResult result = new MessageHandlerResult(
                         new PojoMessageHandlerWholeText(listener, m, session, endpointConfig,
                                 decoderMatch.getTextDecoders(), new Object[1], 0, false, -1, -1),
@@ -442,7 +444,7 @@ public class Util {
             }
         }
 
-        if (results.size() == 0) {
+        if (results.isEmpty()) {
             throw new IllegalArgumentException(sm.getString("wsSession.unknownHandler", listener, target));
         }
 
@@ -453,10 +455,10 @@ public class Util {
             boolean binary, InstanceManager instanceManager) {
         DecoderMatch decoderMatch = matchDecoders(target, endpointConfig, instanceManager);
         if (binary) {
-            if (decoderMatch.getBinaryDecoders().size() > 0) {
+            if (!decoderMatch.getBinaryDecoders().isEmpty()) {
                 return decoderMatch.getBinaryDecoders();
             }
-        } else if (decoderMatch.getTextDecoders().size() > 0) {
+        } else if (!decoderMatch.getTextDecoders().isEmpty()) {
             return decoderMatch.getTextDecoders();
         }
         return null;
@@ -492,11 +494,11 @@ public class Util {
 
         // Step one, split the header into individual extensions using ',' as a
         // separator
-        String unparsedExtensions[] = header.split(",");
+        String[] unparsedExtensions = header.split(",");
         for (String unparsedExtension : unparsedExtensions) {
             // Step two, split the extension into the registered name and
             // parameter/value pairs using ';' as a separator
-            String unparsedParameters[] = unparsedExtension.split(";");
+            String[] unparsedParameters = unparsedExtension.split(";");
             WsExtension extension = new WsExtension(unparsedParameters[0].trim());
 
             for (int i = 1; i < unparsedParameters.length; i++) {
@@ -523,7 +525,7 @@ public class Util {
                 }
                 if (value != null && (value.indexOf(',') > -1 || value.indexOf(';') > -1 || value.indexOf('\"') > -1 ||
                         value.indexOf('=') > -1)) {
-                    throw new IllegalArgumentException(sm.getString("", value));
+                    throw new IllegalArgumentException(sm.getString("util.invalidValue", value));
                 }
                 extension.addParameter(new WsExtensionParameter(name, value));
             }
@@ -533,7 +535,7 @@ public class Util {
 
 
     private static boolean containsDelims(String input) {
-        if (input == null || input.length() == 0) {
+        if (input == null || input.isEmpty()) {
             return false;
         }
         for (char c : input.toCharArray()) {
@@ -622,7 +624,7 @@ public class Util {
 
 
         public boolean hasMatches() {
-            return (textDecoders.size() > 0) || (binaryDecoders.size() > 0);
+            return (!textDecoders.isEmpty()) || (!binaryDecoders.isEmpty());
         }
     }
 
