@@ -671,6 +671,10 @@ public class TestGenerator extends TomcatBaseTest {
         }
     }
 
+    @Test
+    public void testLambdaScriptlets() throws Exception {
+        doTestJsp("lambda.jsp");
+    }
 
     @Test
     public void testInfoConflictNone() throws Exception {
